:mod:`SquareRoot` --- Objet racine carrée
===============================================
Le module :mod:`SquareRoot` introduit la classe :class:`SquareRoot` qui
permet de faire des calculs détaillés sur les racines carrées.

Un objet SquareRoot est construit à partir d'une liste.

.. autoclass:: pyromaths.classes.SquareRoot.SquareRoot
    :members:
    :special-members:
..    :private-members:
      :undoc-members:
      :show-inheritance: